==> basic-1.1.4-sources.jar: net/oschina/suyeer/basic/bean/BHttpResContent.java <==
package net.oschina.suyeer.basic.bean;

import net.oschina.suyeer.basic.util.BJsonUtil;
import net.oschina.suyeer.basic.util.BasicUtil;
import org.apache.commons.lang.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.Serializable;

import static net.oschina.suyeer.basic.util.BConstUtil.SESSION_CURRENT_LOGIN_USER_INFO;

/**
 * Created by jun on 2017/2/16.
 */
public abstract class BHttpResContent<T> implements Serializable {
    private static final long serialVersionUID = -5764986016352461610L;
    private Integer code;
    private String message;
    private T result;
    private transient String funcDes;
    private transient String userIp;
    private transient String reqURL;
    private transient String reqURI;
    private transient String reqQueryURL;
    private transient String reqQueryURI;
    private transient String reqQuery;
    private transient String reqMethod;
    private transient String reqParams;
    private transient String sessionId;
    private transient HttpSession httpSession;
    private transient HttpServletRequest request;
    private transient HttpServletResponse response;
    protected transient Object userInfo;
    protected transient Boolean isLogin;

    public BHttpResContent(HttpServletRequest request, HttpServletResponse response) {
        this.code = 200;
        this.message = "";
        this.reqURI = "";
        this.reqURL = "";
        this.reqQueryURI = "";
        this.reqQueryURL = "";
        this.reqParams = "";
        this.userIp = "";
        this.isLogin = false;
        this.response = response;
        this.request = request;
        if (request != null) {
            this.reqQuery = StringUtils.isNotBlank(request.getQueryString()) ? "?" + request.getQueryString() : "";
            this.reqURI = request.getRequestURI();
            this.reqURL = request.getRequestURL().toString();
            this.reqQueryURI = this.reqURI + this.reqQuery;
            this.reqQueryURL = this.reqURL + this.reqQuery;
            this.reqParams = BJsonUtil.toString(request.getParameterMap());
            this.reqMethod = request.getMethod();
            this.httpSession = request.getSession();
            this.userIp = BasicUtil.getUserIp(request);
            if (this.httpSession != null) {
                this.sessionId = this.httpSession.getId();
                this.userInfo = this.httpSession.getAttribute(SESSION_CURRENT_LOGIN_USER_INFO);
            }
            this.isLogin = (this.userInfo != null);
        }
    }

    public void fillData(Integer code, String message, T result) {
        this.code = code;
        this.message = message;
        this.result = result;
    }

    public void setFuncDes(String funcDes) {
        this.funcDes = funcDes;
    }

    public void setUserSession(Object userObj) {
        if (this.httpSession != null) {
            this.httpSession.setAttribute(SESSION_CURRENT_LOGIN_USER_INFO, userObj);
        }
    }

    public void removeUserSession() {
        if (this.httpSession != null) {
            this.httpSession.removeAttribute(SESSION_CURRENT_LOGIN_USER_INFO);
        }
    }

    public Integer getCode() {
        return this.code;
    }

    public String getMessage() {
        return this.message;
    }

    public T getResult() {
        return this.result;
    }

    public String getReqParams() {
        return this.reqParams;
    }

    public String getSessionId() {
        return this.sessionId;
    }

    public HttpSession getHttpSession() {
        return this.httpSession;
    }

    public String getUserIp() {
        return this.userIp;
    }

    public String getReqMethod() {
        return this.reqMethod;
    }

    public String getFuncDes() {
        return funcDes;
    }

    public String getReqURL() {
        return reqURL;
    }

    public String getReqURI() {
        return reqURI;
    }

    public String getReqQueryURL() {
        return reqQueryURL;
    }

    public String getReqQueryURI() {
        return reqQueryURI;
    }

    public String getReqQuery() {
        return reqQuery;
    }

    public HttpServletRequest getRequest() {
        return request;
    }

    public HttpServletResponse getResponse() {
        return response;
    }

    public abstract Boolean isPermission();

    public abstract Object getUserInfo();

    public abstract Boolean isLogin();
}

==> basic-1.1.10-sources.jar: net/oschina/suyeer/basic/bean/BHttpResContent.java <==
package net.oschina.suyeer.basic.bean;

import net.oschina.suyeer.basic.util.BJsonUtil;
import net.oschina.suyeer.basic.util.BasicUtil;
import org.apache.commons.lang.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.Serializable;

import static net.oschina.suyeer.basic.util.BConstUtil.*;

/**
 * Created by jun on 2017/2/16.
 */
public abstract class BHttpResContent<T> implements Serializable {
    private static final long serialVersionUID = -5764986016352461610L;
    private Integer code;
    private String message;
    private T result;
    private transient String funcDes;
    private transient String userIp;
    private transient String reqURL;
    private transient String reqURI;
    private transient String reqQueryURL;
    private transient String reqQueryURI;
    private transient String reqQuery;
    private transient String reqMethod;
    private transient String reqParams;
    private transient String sessionId;
    private transient String userAgent;
    private transient String wxRedirect;
    private transient HttpSession httpSession;
    private transient HttpServletRequest request;
    private transient HttpServletResponse response;
    protected transient Object userInfo;
    protected transient Object wxUserInfo;
    protected transient Boolean isLogin;
    protected transient Boolean isWxLogin;

    public BHttpResContent(HttpServletRequest request, HttpServletResponse response) {
        this.code = 200;
        this.message = "";
        this.reqURI = "";
        this.reqURL = "";
        this.reqQueryURI = "";
        this.reqQueryURL = "";
        this.reqParams = "";
        this.userIp = "";
        this.isLogin = false;
        this.response = response;
        this.request = request;
        if (request != null) {
            this.reqQuery = StringUtils.isNotBlank(request.getQueryString()) ? "?" + request.getQueryString() : "";
            this.reqURI = request.getRequestURI();
            this.reqURL = request.getRequestURL().toString();
            this.reqQueryURI = this.reqURI + this.reqQuery;
            this.reqQueryURL = this.reqURL + this.reqQuery;
            this.reqParams = BJsonUtil.toString(request.getParameterMap());
            this.reqMethod = request.getMethod();
            this.httpSession = request.getSession();
            this.userIp = BasicUtil.getUserIp(request);
            this.userAgent = request.getHeader(USER_AGENT);
            if (this.httpSession != null) {
                this.sessionId = this.httpSession.getId();
                this.userInfo = this.httpSession.getAttribute(SESSION_CURRENT_LOGIN_USER_INFO);
                this.wxUserInfo = this.httpSession.getAttribute(SESSION_CURRENT_WX_LOGIN_USER_INFO);
            }
            this.isLogin = (this.userInfo != null);
            this.isWxLogin = (this.wxUserInfo != null);
        }
    }

    public void fillData(Integer code, String message, T result) {
        this.code = code;
        this.message = message;
        this.result = result;
    }

    public void setFuncDes(String funcDes) {
        this.funcDes = funcDes;
    }

    public void setWxRedirect(String wxRedirect) {
        this.wxRedirect = wxRedirect;
    }

    public void setUserSession(Object userObj) {
        if (this.httpSession != null) {
            this.httpSession.setAttribute(SESSION_CURRENT_LOGIN_USER_INFO, userObj);
        }
    }

    public void removeUserSession() {
        if (this.httpSession != null) {
            this.httpSession.removeAttribute(SESSION_CURRENT_LOGIN_USER_INFO);
        }
    }

    public void setWxUserSession(Object wxUserObj) {
        if (this.httpSession != null) {
            this.httpSession.setAttribute(SESSION_CURRENT_WX_LOGIN_USER_INFO, wxUserObj);
        }
    }

    public void saveOriginalQueryURI() {
        if (this.httpSession != null) {
            this.httpSession.setAttribute(SESSION_CURRENT_WX_ORIGINAL_QUERY_URI_INFO, this.reqQueryURI);
        }
    }

    public String getOriginalQueryURI() {
        return (String) this.httpSession.getAttribute(SESSION_CURRENT_WX_ORIGINAL_QUERY_URI_INFO);
    }

    public void removeWxUserSession() {
        if (this.httpSession != null) {
            this.httpSession.removeAttribute(SESSION_CURRENT_WX_LOGIN_USER_INFO);
        }
    }

    public Integer getCode() {
        return this.code;
    }

    public String getMessage() {
        return this.message;
    }

    public T getResult() {
        return this.result;
    }

    public String getReqParams() {
        return this.reqParams;
    }

    public String getSessionId() {
        return this.sessionId;
    }

    public HttpSession getHttpSession() {
        return this.httpSession;
    }

    public String getUserIp() {
        return this.userIp;
    }

    public String getReqMethod() {
        return this.reqMethod;
    }

    public String getFuncDes() {
        return funcDes;
    }

    public String getReqURL() {
        return reqURL;
    }

    public String getReqURI() {
        return reqURI;
    }

    public String getReqQueryURL() {
        return reqQueryURL;
    }

    public String getReqQueryURI() {
        return reqQueryURI;
    }

    public String getReqQuery() {
        return reqQuery;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public String getWxRedirect() {
        return wxRedirect;
    }

    public HttpServletRequest getRequest() {
        return request;
    }

    public HttpServletResponse getResponse() {
        return response;
    }

    public abstract Boolean isPermission();

    public abstract Object getUserInfo();

    public abstract Object getWxUserInfo();

    public abstract Boolean isLogin();

    public abstract Boolean isWxLogin();
}
